@@ -23,7 +23,7 @@ from contextlib import redirect_stdout
 from importlib.resources import open_binary, open_text, read_text
 from io import StringIO
 from math import atan2, pi, radians
-from os.path import join as pathjoin, pathsep
+from os.path import pathsep
 from socket import SO_REUSEADDR, SOL_SOCKET, socket
 from sys import stdout
 from threading import Thread
