@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 from contextlib import closing, suppress
-from math import inf, atan2, degrees
+from math import atan2, degrees, inf
 from random import randrange, shuffle
 from socket import socket
 
@@ -9,9 +9,9 @@ AROUND = [5, 2, 1, 0, 3, 6, 7, 8]
 
 def get_moves(y, x):
     """Return tuple of encoded moves."""
-    return ((y - 1, x - 1), (y - 1, x), (y - 1, x + 1),
-            (y,     x - 1), (y,     x), (y,     x + 1),
-            (y + 1, x - 1), (y + 1, x), (y + 1, x + 1))
+    return ((y - 1, x - 1), (y - 1, x), (y - 1, x + 1),     # noqa
+            (y,     x - 1), (y,     x), (y,     x + 1),     # noqa
+            (y + 1, x - 1), (y + 1, x), (y + 1, x + 1))     # noqa
 
 
 def is_wall(maze, y, x):
